jQuery MultiSelect Widget Demo

## Position Utility

Using the jQuery UI position utility to position the menu above the input. This is especially useful when you want collision detection with the bottom of the window, and automatically open the menu above the button.

Please use jQuery 1.4.3 with the positioning option. Bugs in jQuery 1.4.2 prevent the menu from being positioned correctly the first time multiselect is opened in Webkit/IE.

### Center the menu over the button

    $("select").multiselect({
       position: {
          my: 'center',
          at: 'center'

         // only include the "of" property if you want to position
         // the menu against an element other than the button.
         // multiselect automatically sets "of" unless you explictly
         // pass in a value.
       }
    });

### Open the menu upwards

    $("select").multiselect({
       position: {
          my: 'left bottom',
          at: 'left top'
       }
    });